Uint24

Struct Uint24 

#[repr(transparent)]
pub struct Uint24(u32);
24-bit unsigned integer.

Tuple Fields

0: u32

Implementations

Source

impl Uint24

pub const MIN: Self

The smallest value that can be represented by this integer type.

pub const MAX: Self

The largest value that can be represented by this integer type.

pub const fn new(raw: u32) -> Uint24

Create from a u32. Saturates on overflow.

pub const fn checked_new(raw: u32) -> Option<Uint24>

Create from a u32, returning None if the value overflows.

pub const fn to_u32(self) -> u32

Returns this value as an unsigned 32-bit integer.

pub const fn to_be_bytes(self) -> [u8; 3]

pub const fn from_be_bytes(bytes: [u8; 3]) -> Self